@@ -207,7 +207,7 @@ Return the new function symbol derived from TYPE."
 	 (action (nconc (list 'defun sym params doc) body)))
     `(progn
        ,action
-       (setplist ',sym ,property-list)
+       (setplist ',sym '(definition-name ,type @,property-list))
        (symset:add ',type ',type-category 'symbols)
        (run-hooks 'htype-create-hook)
        ',sym)))
@@ -394,10 +394,10 @@ Other paths are simply expanded.  Non-path arguments are returned unchanged."
 
 (defmacro hact (&rest args)
   "Perform action formed from rest of ARGS and return the result.
+The value of `hrule:action' determines what effect this has.
 Alternatively act as a no-op when testing implicit button type contexts.
 First arg may be a symbol or symbol name for either an action type or a
-function.  Runs `action-act-hook' before performing action.
-The value of `hrule:action' determines what effect this has."
+function.  Runs `action-act-hook' before performing action."
   (eval `(cons 'funcall (cons 'hrule:action ',args))))
 
 (defun    actype:act (actype &rest args)
@@ -498,7 +498,7 @@ arguments).  A call to this function is syntactically the same as for
 Return symbol created when successful, else nil."
   `(progn
      (symtable:add ',type symtable:actypes)
-     (htype:create ,type actypes ,doc ,params ,default-action '(definition-name ,type))))
+     (htype:create ,type actypes ,doc ,params ,default-action nil)))
 
 (defalias 'defact 'actype:create)
 (put      'actype:create 'lisp-indent-function 'defun)
