@@ -735,11 +735,15 @@ others who use a different value!")
 ;;; hbut class - abstract
 ;;; ========================================================================
 
-(defun    hbut:act (hbut)
-  "Perform action for explicit or implicit Hyperbole button symbol HBUT."
-  (if hbut (apply hrule:action
-		  (hattr:get hbut 'actype)
-		  (hattr:get hbut 'args))))
+(defun    hbut:act (&optional hbut)
+  "Perform action for optional explicit or implicit Hyperbole button symbol HBUT.
+Default is 'hbut:current."
+  (unless hbut
+    (setq hbut 'hbut:current))
+  (when hbut
+    (apply hrule:action
+	   (hattr:get hbut 'actype)
+	   (hattr:get hbut 'args))))
 
 (defun    hbut:action (hbut)
   "Return appropriate action for Hyperbole button symbol HBUT."
@@ -751,10 +755,11 @@ others who use a different value!")
 		   atype
 		 (or action (actype:action atype))))
       ;; Must be an implicit button.
-      (if (fboundp atype) atype))))
+      (when (fboundp atype) atype))))
 
 (defun    hbut:at-p ()
-  "Return symbol for explicit or implicit Hyperbole button at point or nil."
+  "Return symbol for explicit or implicit Hyperbole button at point or nil.
+Then use (hbut:act) to activate the button."
   (or (ebut:at-p) (ibut:at-p)))
 
 
@@ -1058,11 +1063,12 @@ include delimiters when INCLUDE-DELIMS is non-nil)."
 (defun    hbut:outside-comment-p ()
   "Return t if within a programming language buffer and prior regexp match is outside a comment, else nil."
   (when (and (derived-mode-p 'prog-mode)
-	     (not (eq major-mode 'lisp-interaction-mode)))
+	     (not (eq major-mode 'lisp-interaction-mode))
+	     (not (memq major-mode hui-select-markup-modes)))
     ;; Match is outside of a programming language comment
     (not (nth 4 (syntax-ppss)))))
 
-(defun hbut:rename (but)
+(defun    hbut:rename (but)
   "Interactively rename the Hyperbole button BUT from the current buffer."
   (cond ((ebut:is-p but)
          (ebut:to (ebut:key but))
@@ -1071,7 +1077,7 @@ include delimiters when INCLUDE-DELIMS is non-nil)."
          (ibut:to (ibut:key but))
          (call-interactively #'hui:ibut-rename))
         (t
-	     (hypb:error "(hbut:rename): Button is invalid; it has no attributes"))))
+	 (hypb:error "(hbut:rename): Button is invalid; it has no attributes"))))
 
 (defun    hbut:report (&optional arg)
   "Pretty print the attributes of a button or buttons.
@@ -1079,8 +1085,8 @@ include delimiters when INCLUDE-DELIMS is non-nil)."
 Takes an optional ARG interpreted as follows:
   a button symbol - report on that button;
   nil             - report on button at point, if any;
-  integer > 0     - report on all explicit buttons in buffer, alphabetize;
-  integer < 1     - report on all explicit buttons in occurrence order.
+  integer > 0     - report on all explicit buttons in buffer, in lexicographical order;
+  integer < 1     - report on all explicit buttons in buffer, in occurrence order.
 
 Return number of buttons reported on or nil if none."
   (setq arg (cond ((or (integerp arg) (symbolp arg)) arg)
@@ -1104,8 +1110,7 @@ Return number of buttons reported on or nil if none."
 	 (attribs)
 	 ;; Ensure these do not invoke with-output-to-temp-buffer a second time.
 	 (temp-buffer-show-hook)
-	 (temp-buffer-show-function)
-	 )
+	 (temp-buffer-show-function))
     (if lbl-lst
 	(progn
 	  (with-help-window buf-name
@@ -1135,8 +1140,7 @@ Return number of buttons reported on or nil if none."
 		      ;;			   (memq 'action attribs)
 		      ;;			 (memq 'categ attribs))
 		      attribs)
-		     (terpri))
-		 ))
+		     (terpri))))
 	     lbl-lst))
 	  (length lbl-lst)))))
 
@@ -1214,56 +1218,61 @@ With optional KEY-ONLY, returns only the label key for button.
 
 Any labeled implicit button must contain at least two characters,
 excluding delimiters, not just one."
-  (let* ((opoint (point))
-	 (label-key-start-end (ibut:label-p nil nil nil t t))
-	 (lbl-key (car label-key-start-end)))
-    (unwind-protect
-	(when (not (hbut:outside-comment-p))
-	  ;; Skip past any optional label and separators
-	  (when label-key-start-end
-	    (goto-char (nth 2 label-key-start-end)) 
-	    (when (looking-at ibut:label-separator-regexp)
-	      ;; Move past up to 2 possible characters of ibut
-	      ;; delimiters; this prevents recognizing labeled,
-	      ;; delimited ibuts of a single character but no one
-	      ;; should need that.
-	      (goto-char (min (+ 2 (match-end 0)) (point-max)))))
+  ;; Since the Smart Keys handle end-of-line separately from whether
+  ;; point is within an implicit button, always report not within one
+  ;; when point is at the end of a line.  -- RSW, 02-16-2020
+  (unless (eolp)
+    (let* ((opoint (point))
+	   (label-key-start-end (ibut:label-p nil nil nil t t))
+	   (lbl-key (car label-key-start-end)))
+      (unwind-protect
+	  (progn
+	    (when (not (hbut:outside-comment-p))
+	      ;; Skip past any optional label and separators
+	      (when label-key-start-end
+		(goto-char (nth 2 label-key-start-end))
+		(when (looking-at ibut:label-separator-regexp)
+		  ;; Move past up to 2 possible characters of ibut
+		  ;; delimiters; this prevents recognizing labeled,
+		  ;; delimited ibuts of a single character but no one
+		  ;; should need that.
+		  (goto-char (min (+ 2 (match-end 0)) (point-max))))))
 
-	  ;; Check for an implicit button at current point, record its
-	  ;; attributes and return a button symbol for it.
-	  (let ((types (htype:category 'ibtypes))
-		;; Global var used in (hact) function, don't delete.
-		(hrule:action 'actype:identity)
-		(itype)
-		(args)
-		(is-type))
-	    (unless key-only
-	      (hattr:clear 'hbut:current))
-	    (while (and (not is-type) types)
-	      (setq itype (car types))
-	      (if (and itype (setq args (funcall itype)))
-		  (setq is-type itype)
-		(setq types (cdr types))))
-	    (when is-type
-	      (when lbl-key
-		(hattr:set 'hbut:current 'lbl-key lbl-key))
-	      (if key-only
-		  (hattr:get 'hbut:current 'lbl-key)
-		(hattr:set 'hbut:current 'loc (save-excursion
-						(hbut:key-src 'full)))
+	    ;; Check for an implicit button at current point, record its
+	    ;; attributes and return a button symbol for it.
+	    (let ((types (htype:category 'ibtypes))
+		  ;; Global var used in (hact) function, don't delete.
+		  (hrule:action 'actype:identity)
+		  (itype)
+		  (args)
+		  (is-type))
+	      (unless key-only
+		(hattr:clear 'hbut:current))
+	      (while (and (not is-type) types)
+		(setq itype (car types))
+		(if (and itype (setq args (funcall itype)))
+		    (setq is-type itype)
+		  (setq types (cdr types))))
+	      (when is-type
 		(hattr:set 'hbut:current 'categ is-type)
-		(or (hattr:get 'hbut:current 'args)
-		    (not (listp args))
-		    (progn
-		      (hattr:set 'hbut:current 'actype
-				 (or
-				  ;; Hyperbole action type
-				  (symtable:actype-p (car args))
-				  ;; Regular Emacs Lisp function symbol
-				  (car args)))
-		      (hattr:set 'hbut:current 'args (cdr args))))
-		'hbut:current))))
-      (goto-char opoint))))
+		(when lbl-key
+		  (hattr:set 'hbut:current 'lbl-key lbl-key))
+		(if key-only
+		    (hattr:get 'hbut:current 'lbl-key)
+		  (hattr:set 'hbut:current 'loc (save-excursion
+						  (hbut:key-src 'full)))
+		  (or (hattr:get 'hbut:current 'args)
+		      (not (listp args))
+		      (progn
+			(hattr:set 'hbut:current 'actype
+				   (or
+				    ;; Hyperbole action type
+				    (symtable:actype-p (car args))
+				    ;; Regular Emacs Lisp function symbol
+				    (car args)))
+			(hattr:set 'hbut:current 'args (cdr args))))
+		  'hbut:current))))
+	(goto-char opoint)))))
 
 (defun    ibut:at-type-p (ibut-type-symbol)
   "Return non-nil if point is on a button of type IBUT-TYPE-SYMBOL.
@@ -1356,10 +1365,10 @@ current."
 
 (defun    ibut:label-p (&optional as-label start-delim end-delim pos-flag two-lines-flag)
   "Return key for the Hyperbole implicit button label that point is within, else nil.
-This is the normalized key form of an optional label that may precede an implicit button.
-Use `ibut:at-p' instead to test if point is on either the
-implicit button itself or the label.  Assumes point is within the
-first line of any button label.
+This is the normalized key form of an optional label that may
+precede an implicit button.  Use `ibut:at-p' instead to test if
+point is on either the implicit button text itself or the label.
+Assumes point is within the first line of any button label.
 
 All following arguments are optional.  If AS-LABEL is non-nil,
 label is returned rather than the key derived from the label.
@@ -1457,32 +1466,33 @@ move to the first occurrence of the button."
   "Find the nearest implicit button with LBL-KEY (a label or label key) within the visible portion of the current buffer.
 Leave point inside the button text or its optional label, if it has one.
 Return the symbol for the button, else nil."
-  ;; Handle a label given rather than a label key
-  (if (string-match-p "\\s-" lbl-key)
-      (setq lbl-key (ibut:label-to-key lbl-key)))
-  (let ((regexp (hbut:label-regexp lbl-key t))
-	pos
-	found)
-    (save-excursion
-      ;; Since point might be in the middle of the matching button,
-      ;; move to the start of line to ensure don't miss it when
-      ;; searching forward.
-      (forward-line 0)
-      ;; re-search forward
-      (while (and (not found) (re-search-forward regexp nil t))
-	(setq pos (match-beginning 0)
-	      ;; Point might be on closing delimiter of ibut in which
-	      ;; case ibut:label-p returns nil; move back one
-	      ;; character to prevent this.
-	      found (progn (goto-char (1- (point)))
-			   (equal (ibut:at-p t) lbl-key))))
-      ;; re-search backward
-      (while (and (not found) (re-search-backward regexp nil t))
-	(setq pos (match-beginning 0)
-	      found (equal (ibut:label-p nil nil nil nil t) lbl-key))))
-    (when found
-      (goto-char pos)
-      (ibut:at-p))))
+  (when lbl-key
+    ;; Handle a label given rather than a label key
+    (if (string-match-p "\\s-" lbl-key)
+	(setq lbl-key (ibut:label-to-key lbl-key)))
+    (let ((regexp (hbut:label-regexp lbl-key t))
+	  pos
+	  found)
+      (save-excursion
+	;; Since point might be in the middle of the matching button,
+	;; move to the start of line to ensure don't miss it when
+	;; searching forward.
+	(forward-line 0)
+	;; re-search forward
+	(while (and (not found) (re-search-forward regexp nil t))
+	  (setq pos (match-beginning 0)
+		;; Point might be on closing delimiter of ibut in which
+		;; case ibut:label-p returns nil; move back one
+		;; character to prevent this.
+		found (progn (goto-char (1- (point)))
+			     (equal (ibut:at-p t) lbl-key))))
+	;; re-search backward
+	(while (and (not found) (re-search-backward regexp nil t))
+	  (setq pos (match-beginning 0)
+		found (equal (ibut:label-p nil nil nil nil t) lbl-key))))
+      (when found
+	(goto-char pos)
+	(ibut:at-p)))))
 
 ;;; ------------------------------------------------------------------------
 (defconst ibut:label-start "<["
