@@ -81,10 +81,7 @@ If the value of 'hpath:mswindows-mount-prefix' changes, then re-initialize this
 (defconst hpath:mswindows-path-regexp "\\`.*\\.*[a-zA-Z0-9_.]"
   "Regular expression matching the start of an MSWindows path that does not start with a drive letter but contains directory separators.")
 
-(defvar hpath:mswindows-path-posix-mount-alist nil
-  "Automatically set alist of (window-path-prefix . posix-mount-point) elements.")
-
-(defvar hpath:directory-expand-alist nil
+(defvar hpath:posix-mount-point-to-mswindows-alist nil
   "Automatically set alist of (posix-mount-point . window-path-prefix) elements.
 Used to expand posix mount points to Windows UNC paths during posix-to-mswindows conversion.")
 
@@ -110,9 +107,18 @@ If path begins with an MSWindows drive letter, prefix the converted path with th
   path)
 
 (defun hpath:mswindows-to-posix-separators (path)
-  "Replace all backslashes with forward slashes in PATH and expand the path against `directory-abbrev-alist', if possible.
-Path must be a string or an error will be triggered."
-  (replace-regexp-in-string "\\\\" "/" (abbreviate-file-name path) nil t))
+  "Replace all backslashes with forward slashes in PATH and abbreviate the path if possible.
+Path must be a string or an error will be triggered.  See
+'abbreviate-file-name' for how path abbreviation is handled."
+    (setq path (replace-regexp-in-string "\\\\" "/" path)
+          ;; Downcase any host and domain for mount-point matching
+          path (if (string-match "\\`//[^/:]+" path)
+                   (concat (downcase (match-string 0 path))
+                           (substring path (match-end 0)))
+                 path)
+          path (hpath:abbreviate-file-name path)
+          path (replace-regexp-in-string (regexp-quote "\\`") "" path)
+          path (replace-regexp-in-string (regexp-quote "\\>") "" path)))
 
 ;;;###autoload
 (defun hpath:posix-to-mswindows (path)
@@ -142,8 +148,8 @@ If path begins with an optional mount prefix, 'hpath:mswindows-mount-prefix', fo
   "Replace all forward slashes with backslashes in PATH and abbreviate the path if possible.
 Path must be a string or an error will be triggered.  See
 'abbreviate-file-name' for how path abbreviation is handled."
-  (let ((directory-abbrev-alist hpath:directory-expand-alist))
-    (replace-regexp-in-string "/" "\\\\" (abbreviate-file-name path))))
+  (let ((directory-abbrev-alist hpath:posix-mount-point-to-mswindows-alist))
+    (replace-regexp-in-string "/" "\\\\" (hpath:abbreviate-file-name path))))
 
 (defun hpath:posix-path-p (path)
   "Return non-nil if PATH looks like a Posix path."
@@ -181,33 +187,50 @@ Path must be a string or an error will be triggered.  See
 Call this function manually if mount points change after Hyperbole is loaded."
   (interactive)
   (when (not hyperb:microsoft-os-p)
-    (let ((mount-points-to-add
-	   ;; Sort alist of (path-mounted . mount-point) elements from shortest
-	   ;; to longest path so thDat the longest path is selected first within
-	   ;; 'directory-abbrev-alist' (elements are added in reverse order).
-	   (sort
-	    ;; Convert plist to alist for sorting.
-	    (hypb:map-plist (lambda (path mount-point)
-			       (if (string-match "\\`\\([a-zA-Z]\\):\\'" path)
-				   ;; Drive letter must be downcased
-				   ;; in order to work when converted back to Posix.
-				   (setq path (concat "/" (downcase (match-string 1 path)))))
-			       ;; Assume all mounted Windows paths are
-			       ;; lowercase for now.
-			       (cons (downcase path) mount-point))
-			     ;; Return a plist of MSWindows path-mounted mount-point pairs.
-			     (split-string (shell-command-to-string (format "df -a -t drvfs 2> /dev/null | sort | uniq | grep -v '%s' | sed -e 's+ .*[-%%] /+ /+g'" hpath:posix-mount-points-regexp))))
-	    (lambda (cons1 cons2) (<= (length (car cons1)) (length (car cons2))))))
-	  path mount-point)
-      (mapc (lambda (path-and-mount-point)
+    (let (mount-points-alist
+          mount-points-to-add)
+      ;; Convert plist to alist for sorting.
+      (hypb:map-plist (lambda (path mount-point)
+			(when (string-match "\\`\\([a-zA-Z]\\):\\'" path)
+			  (setq path (concat "/" (match-string 1 path))))
+			;; Drive letter must be downcased
+			;; in order to work when converted back to Posix.
+			;; Assume all mounted Windows paths are
+			;; lowercase for now.
+                        (setq path (downcase path))
+                        (push (cons (downcase path) mount-point)
+                              mount-points-to-add)
+                        ;; If a network share with a domain
+                        ;; name, also add an entry WITHOUT the
+                        ;; domain name to the mount points
+                        ;; table since Windows paths often omit
+                        ;; the domain.
+                        (when (string-match "\\`\\([\\/][\\/][^.\\/]+\\)\\([^\\/]+\\)" path)
+                          (push (cons (concat (match-string 1 path)
+                                              (substring path (match-end 0)))
+                                      mount-point)
+                                mount-points-to-add)))
+		      ;; Return a plist of MSWindows path-mounted mount-point pairs.
+		      (split-string (shell-command-to-string (format "df -a -t drvfs 2> /dev/null | sort | uniq | grep -v '%s' | sed -e 's+ .*[-%%] /+ /+g'" hpath:posix-mount-points-regexp))))
+      ;; Sort alist of (path-mounted . mount-point) elements from shortest
+      ;; to longest path so that the longest path is selected first within
+      ;; 'directory-abbrev-alist' (elements are added in reverse order).
+      (setq mount-points-to-add
+            (sort mount-points-to-add
+                  (lambda (cons1 cons2) (<= (length (car cons1)) (length (car cons2))))))
+      (let (path
+            mount-point)
+        (mapc (lambda (path-and-mount-point)
 		(setq path (car path-and-mount-point)
 		      mount-point (cdr path-and-mount-point))
-		(add-to-list 'directory-abbrev-alist (cons (format "\\`%s\\>" (regexp-quote path))
-							   mount-point)))
-	      mount-points-to-add)
+                ;; Don't abbreviate /mnt or /cygdrive to /, skip this entry.
+                (unless (equal mount-point "/")
+		  (add-to-list 'directory-abbrev-alist (cons (format "\\`%s\\>" (regexp-quote path))
+							     mount-point))))
+	      mount-points-to-add))
       ;; Save the reverse of each mount-points-to-add so
       ;; can expand paths when going from posix-to-mswindows.
-      (setq hpath:directory-expand-alist
+      (setq hpath:posix-mount-point-to-mswindows-alist
 	    (mapcar (lambda (elt) (cons (concat "\\`" (cdr elt) "\\>")
                                         (car elt))) mount-points-to-add))
       mount-points-to-add)))
@@ -503,7 +526,7 @@ use with `string-match'.")
   "Regexp that matches to a Markdown file suffix.")
 
 (defconst hpath:markup-link-anchor-regexp
-  "\\`\\(#?[^#]+\\)\\(#\\)\\([^\]\[#^{}<>\"`'\\\n\t\f\r]*\\)"
+  "\\`\\(#?[^#]*[^#.]\\)?\\(#\\)\\([^\]\[#^{}<>\"`'\\\n\t\f\r]*\\)"
   "Regexp that matches a markup filename followed by a hash (#) and an optional in-file anchor name.
 Group 3 is the anchor name.")
 
@@ -536,12 +559,19 @@ These are used to indicate how to display or execute the pathname.
 ;;; Public functions
 ;;; ************************************************************************
 
+(defun hpath:abbreviate-file-name (path)
+  "Same as `abbreviate-file-name' but disables tramp-mode.
+This prevents improper processing of hargs with colons in them, e.g. `actypes::link-to-file'."
+  (let (tramp-mode)
+    (abbreviate-file-name path)))
+
 (defun hpath:absolute-to (path &optional default-dirs)
   "Return PATH as an absolute path relative to one directory from optional DEFAULT-DIRS or `default-directory'.
 Return PATH unchanged when it is not a valid path or when DEFAULT-DIRS
 is invalid.  DEFAULT-DIRS when non-nil may be a single directory or a list of
 directories.  The first one in which PATH is found is used."
   (cond ((not (and (stringp path)
+		   (not (hypb:object-p path))
                    (hpath:is-p (hpath:trim path) nil t)))
          path)
         ((progn (setq path (hpath:trim path))
@@ -565,9 +595,10 @@ directories.  The first one in which PATH is found is used."
 (defun hpath:tramp-file-name-regexp ()
   "Return a modified `tramp-file-name-regexp' for matching to the beginning of a remote file name.
 Removes bol anchor and removes match to empty string if present."
-  (let ((tramp-regexp (car (if (fboundp 'tramp-file-name-structure)
-			       (tramp-file-name-structure)
-			     tramp-file-name-structure))))
+  (let* ((tramp-localname-regexp "[^[:cntrl:]]*\\'")
+	 (tramp-regexp (car (if (fboundp 'tramp-file-name-structure)
+				(tramp-file-name-structure)
+			      tramp-file-name-structure))))
     (substring-no-properties (replace-regexp-in-string "\\\\'" "" tramp-regexp) 1)))
 
 (defun hpath:remote-at-p ()
@@ -866,7 +897,9 @@ buffer but don't display it."
     (when (string-match hpath:markup-link-anchor-regexp path)
       (setq hash t
 	    anchor (match-string 3 path)
-	    path (substring path 0 (match-end 1))))
+	    path (if (match-end 1)
+		     (substring path 0 (match-end 1))
+		   buffer-file-name)))
     (setq path (hpath:substitute-value path)
 	  filename (hpath:absolute-to path default-directory))
     (if noselect
@@ -957,7 +990,8 @@ buffer but don't display it."
 				     (subst-char-in-string ?- ?\  anchor))))
 		  (goto-char (point-min))
 		  (if (re-search-forward (format
-					  (cond ((or (string-match hpath:markdown-suffix-regexp buffer-file-name)
+					  (cond ((or (and buffer-file-name
+							  (string-match hpath:markdown-suffix-regexp buffer-file-name))
 						     (memq major-mode hpath:shell-modes))
 						 hpath:markdown-section-pattern)
 						((eq major-mode 'texinfo-mode)
@@ -1049,7 +1083,7 @@ See also `hpath:internal-display-alist' for internal, `window-system' independen
 			     (cons "next" hpath:external-display-alist-macos)))))))
 
 (defun hpath:is-p (path &optional type non-exist)
-  "Return normalized PATH if PATH is a Posix or MSWindows path, else nil.
+  "Return normalized PATH as a URL if PATH is a Posix or MSWindows path, else nil.
 If optional TYPE is the symbol 'file or 'directory, then only that path type
 is accepted as a match.  The existence of the path is checked only for
 locally reachable paths (Info paths are not checked).  With optional NON-EXIST,
@@ -1068,6 +1102,11 @@ path form is what is returned for PATH."
       (when (string-match hpath:prefix-regexp path)
 	(setq modifier (substring path 0 1)
 	      path (substring path (match-end 0))))
+      (when (string-match "\\`file://" path)
+	(setq path (substring path (match-end 0))))
+      (when (string-match hpath:prefix-regexp path)
+	(setq modifier (substring path 0 1)
+	      path (substring path (match-end 0))))
       (setq path (hpath:mswindows-to-posix path))
       (and (not (or (string-equal path "")
 		    (string-match "\\`\\s-\\|\\s-\\'" path)))
@@ -1075,7 +1114,8 @@ path form is what is returned for PATH."
 	   (setq path (hbut:key-to-label (hbut:label-to-key path)))
 	   (or (not (string-match "[()]" path))
 	       (string-match "\\`([^ \t\n\r\)]+)[ *A-Za-z0-9]" path))
-	   (if (string-match "\\$\{[^\}]+}" path)
+	   ;; Allow for @{ and @} in texinfo-mode
+	   (if (string-match "\\$@?\{[^\}]+@?\}" path)
 	       ;; Path may be a link reference with a suffix component
 	       ;; following a comma or # symbol, so temporarily strip
 	       ;; these, if any, before expanding any embedded variables.
@@ -1178,7 +1218,8 @@ Is a no-op if the function `push-tag-mark' is not available."
   "Return PATH relative to optional DEFAULT-DIR or `default-directory'.
 Expand any other valid path.  Return PATH unchanged when it is not a
 valid path."
-  (cond ((not (stringp path))
+  (cond ((not (and (stringp path)
+		   (not (hypb:object-p path))))
 	 path)
 	((and (setq path (hpath:trim path))
 	      (not (hpath:is-p path)))
@@ -1243,12 +1284,15 @@ in-buffer path will not match."
   ;; Uses free variables `match' and `start' from `hypb:replace-match-string'.
   (substitute-in-file-name
     (hypb:replace-match-string
-      "\\$\{[^\}]+}"
+      "\\$@?\{\\([^\}]+\\)@?\}"
       path
       (lambda (str)
 	(let* ((var-group (substring path match start))
-	       (var-name (substring path (+ match 2) (1- start)))
 	       (rest-of-path (substring path start))
+	       (var-ext (substring path (match-beginning 1) (match-end 1)))
+	       (var-name (if (= ?@ (aref var-ext (1- (length var-ext))))
+			     (substring var-ext 0 -1)
+			   var-ext))
 	       (trailing-dir-sep-flag (and (not (string-empty-p rest-of-path))
 					   (memq (aref rest-of-path 0) '(?/ ?\\))))
 	       (sym (intern-soft var-name)))
@@ -1260,7 +1304,7 @@ in-buffer path will not match."
 		       ;; invalid local path but this may be called when
 		       ;; testing for implicit button matches where no error
 		       ;; should occur, so catch the error and ignore variable
-		       ;; expansion in such a case.  -- RSW, 8/26/2019
+		       ;; expansion in such a case.  -- RSW, 08-26-2019
 		       (condition-case nil
 			   (hpath:substitute-dir var-name rest-of-path)
 			 (error rest-of-path)))
