@@ -41,7 +41,7 @@
 ;;;### (autoloads nil "hbut" "hbut.el" (0 0 0 0))
 ;;; Generated autoloads from hbut.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hbut" '("ibut:" "ibtype:create" "defib" "map-" "hattr:summarize" "hbut:" "ebut:")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hbut" '("ibut:" "ibtype:create" "defib" "map-" "hattr:summarize" "hbut:s" "ebut:")))
 
 ;;;***
 
@@ -95,7 +95,7 @@ Initialize Hyperbole support for Gnus Usenet news reading.
 ;;;### (autoloads nil "hibtypes" "hibtypes.el" (0 0 0 0))
 ;;; Generated autoloads from hibtypes.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hibtypes" '("ctags" "cscope" "completion" "annot-bib" "action" "hlink" "hibtypes-path-line-and-col-regexp" "hyp-" "Info-node" "glink" "grep-msg" "gnus-push-button" "tex" "pat" "etags" "eli" "dir-summary" "debugger-source" "rfc" "ripgrep-msg" "id-cflow" "ilink" "ipython-stack-frame" "mail-address" "markdown-" "man-apropos" "function-in-buffer")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hibtypes" '("ctags" "cscope" "completion" "annot-bib" "action" "hlink" "hibtypes-path-line-and-col-regexp" "hyp-" "Info-node" "glink" "grep-msg" "gnus-push-button" "tex" "parse-label-and-file" "pat" "etags" "eli" "dir-summary" "debugger-source" "rfc" "ripgrep-msg" "id-cflow" "ilink" "ipython-stack-frame" "mail-address" "markdown-" "man-apropos" "function-in-buffer")))
 
 ;;;***
 
@@ -254,10 +254,12 @@ Leave TO-WINDOW as the selected window.
 \(fn TO-WINDOW)" t nil)
 
 (autoload 'hkey-throw "hmouse-drv" "\
-Throw either a displayable item at point or the current buffer for display in RELEASE-WINDOW.
+Throw one of: the active (highlighted) region, a displayable item at point or the current buffer for display in RELEASE-WINDOW.
+With optional prefix arg THROW-REGION-FLAG, throw the current region
+even if not active.
 The selected window does not change.
 
-\(fn RELEASE-WINDOW)" t nil)
+\(fn RELEASE-WINDOW &optional THROW-REGION-FLAG)" t nil)
 
 (autoload 'hkey-buffer-to "hmouse-drv" "\
 Use ace-window to choose a FROM-WINDOW whose buffer will also be displayed in the chosen TO-WINDOW.
@@ -357,7 +359,7 @@ the current window.  By default, it is displayed according to the setting of
 
 \(fn &optional BUFFER CURRENT-WINDOW)" nil nil)
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hmouse-drv" '("smart-scroll-" "hkey-" "hmouse-" "quit-window" "action-" "assist-")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hmouse-drv" '("smart-scroll-" "hkey-" "hmouse-" "quit-window" "mouse-drag-mode-line" "action-" "assist-")))
 
 ;;;***
 
@@ -757,7 +759,7 @@ Initialize Hyperbole support for Rmail mail reading.
 ;;;### (autoloads nil "hsys-org" "hsys-org.el" (0 0 0 0))
 ;;; Generated autoloads from hsys-org.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hsys-org" '("hsys-org-" "org-")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hsys-org" '("hsys-org-" "org-" "inhibit-hsys-org")))
 
 ;;;***
 
@@ -1329,7 +1331,7 @@ Nil value of MAX-MATCHES means find all matches, t value means find all matches
 but omit file headers, negative values mean find up to the inverse of that
 number of entries and omit file headers.
 
-Returns number of entries matched.  See also documentation for the variable
+Return number of entries matched.  See also documentation for the variable
 hyrolo-file-list.
 
 \(fn REGEXP &optional MAX-MATCHES HYROLO-FILE-OR-BUFS COUNT-ONLY NO-DISPLAY)" t nil)
@@ -1339,14 +1341,14 @@ Kill a rolo entry given by NAME within `hyrolo-file-list'.
 With prefix argument, prompts for optional FILE to locate entry within.
 NAME may be of the form: parent/child to kill child below a parent entry
 which begins with the parent string.
-Returns t if entry is killed, nil otherwise.
+Return t if entry is killed, nil otherwise.
 
 \(fn NAME &optional FILE)" t nil)
 
 (autoload 'hyrolo-sort "hyrolo" "\
 Sort up to 14 levels of entries in HYROLO-FILE (default is personal rolo).
 Assumes entries are delimited by one or more `*'characters.
-Returns list of number of groupings at each entry level.
+Return list of number of groupings at each entry level.
 
 \(fn &optional HYROLO-FILE)" t nil)
 
@@ -1368,7 +1370,7 @@ Nil value of MAX-MATCHES means find all matches, t value means find all matches
 but omit file headers, negative values mean find up to the inverse of that
 number of entries and omit file headers.
 
-Returns number of entries matched.  See also documentation for the variable
+Return number of entries matched.  See also documentation for the variable
 hyrolo-file-list.
 
 \(fn STRING &optional MAX-MATCHES HYROLO-FILE COUNT-ONLY NO-DISPLAY)" t nil)
